@@ -27,7 +27,7 @@ extern "C" {
 
 #define TICKIT_VERSION_MAJOR 0
 #define TICKIT_VERSION_MINOR 4
-#define TICKIT_VERSION_PATCH 3
+#define TICKIT_VERSION_PATCH 4
 
 int tickit_version_major(void);
 int tickit_version_minor(void);
@@ -123,6 +123,7 @@ typedef enum {
   TICKIT_PEN_STRIKE,     /* bool */
   TICKIT_PEN_ALTFONT,    /* number */
   TICKIT_PEN_BLINK,      /* bool */
+  TICKIT_PEN_SIZEPOS,    /* number */
 
   TICKIT_N_PEN_ATTRS
 } TickitPenAttr;
@@ -139,6 +140,13 @@ enum {
   TICKIT_PEN_BG_DESC = 0x100 + TICKIT_PEN_BG,
 };
 
+typedef enum {
+  TICKIT_PEN_SIZEPOS_NORMAL,
+  TICKIT_PEN_SIZEPOS_SMALL,  // currently undocumented and unhandled by any driver
+  TICKIT_PEN_SIZEPOS_SUPERSCRIPT,
+  TICKIT_PEN_SIZEPOS_SUBSCRIPT,
+} TickitPenSizePosition;
+
 typedef enum {
   TICKIT_PEN_UNDER_NONE,
   TICKIT_PEN_UNDER_SINGLE,
@@ -271,6 +279,8 @@ typedef enum {
 enum {
   TICKIT_MOUSEWHEEL_UP = 1,
   TICKIT_MOUSEWHEEL_DOWN,
+  TICKIT_MOUSEWHEEL_LEFT,
+  TICKIT_MOUSEWHEEL_RIGHT,
 };
 
 typedef struct {
