@@ -123,6 +123,8 @@ static void evloop_destroy(void *data)
     free(evdata->pollfds);
   if(evdata->pollwatches)
     free(evdata->pollwatches);
+  if(evdata->signums)
+    free(evdata->signums);
 
   if(signal_observer == evdata)
     signal_observer = NULL;
